package com.jiuqi.office.excel;

import com.jiuqi.grid.GridData;
import java.io.IOException;
import java.io.OutputStream;
import java.util.HashMap;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

/* loaded from: com_jiuqi_office_excel.jar:com/jiuqi/office/excel/SimpleExportor.class */
public class SimpleExportor {
    public static final int EXPORT_MODE_2003 = 0;
    public static final int EXPORT_MODE_2007_LATER = 1;
    public static final int EXPORT_MODE_2007_LATER_SUPER = 2;
    private boolean autoAdjust;
    private boolean addTitle;
    private String title;
    private GridData reportData;
    private HashMap cellStyleHashMap;
    private int transparentColor;
    private boolean doNotCheckNumberIsNull;
    private HashMap HSSFFontMap;
    private String preSheetName;
    public static final int DEFAULT_EXPORT_MODE = 0;
    public static final int MAX_ROW = 65536;

    public SimpleExportor(GridData gridData) {
        this(null, gridData);
    }

    public SimpleExportor(String title, GridData gridData) {
        this.reportData = (GridData) gridData.clone();
        this.title = title;
        this.cellStyleHashMap = new HashMap();
        this.HSSFFontMap = new HashMap();
        this.transparentColor = -16777201;
        this.doNotCheckNumberIsNull = false;
        this.preSheetName = "Sheet";
        this.addTitle = title != null;
    }

    public void setAutoAdjust(boolean autoAdjust) {
        this.autoAdjust = autoAdjust;
    }

    public void setAddTitle(boolean addTitle) {
        this.addTitle = addTitle;
    }

    public boolean isAutoAdjust() {
        return this.autoAdjust;
    }

    public boolean isAddTitle() {
        return this.addTitle;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public void setTransparentColor(int transparentColor) {
        this.transparentColor = transparentColor;
    }

    public boolean isDoNotCheckNumberIsNull() {
        return this.doNotCheckNumberIsNull;
    }

    public void setDoNotCheckNumberIsNull(boolean doNotCheckNumberIsNull) {
        this.doNotCheckNumberIsNull = doNotCheckNumberIsNull;
    }

    public String getPreSheetName() {
        return this.preSheetName;
    }

    public void setPreSheetName(String preSheetName) {
        this.preSheetName = preSheetName;
    }

    public void export(OutputStream outStream) throws ExcelException {
        export(outStream, 0);
    }

    public void export(OutputStream outStream, int mode) throws ExcelException {
        if (mode == 0 && this.reportData != null && this.reportData.getRowCount() > 65536) {
            exportHSSFWorkbook(outStream);
            return;
        }
        Workbook wb = createWorkbook(mode);
        Sheet sheet = wb.createSheet(String.valueOf(this.preSheetName) + 0);
        this.cellStyleHashMap.clear();
        WorksheetWriter sheetWriter = new WorksheetWriter(wb, sheet, this.reportData, this.cellStyleHashMap);
        sheetWriter.setPreSheetName(this.preSheetName);
        sheetWriter.setHSSFFontMap(this.HSSFFontMap);
        sheetWriter.setAddTitle(this.addTitle);
        sheetWriter.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
        if (this.addTitle) {
            sheetWriter.setTitle(this.title);
        }
        sheetWriter.setAutoAdjust(this.autoAdjust);
        sheetWriter.setTransparentColor(this.transparentColor);
        sheetWriter.writeWorkSheet();
        try {
            wb.write(outStream);
        } catch (IOException e) {
            throw new ExcelException(e);
        }
    }

    private void exportHSSFWorkbook(OutputStream outStream) throws ExcelException {
        int oldRowCountPerPage = this.reportData.getRowCountPerPage();
        int localBottomRow = this.reportData.getScrollBottomRow();
        int localTopRow = this.reportData.getScrollTopRow();
        this.reportData.setScrollBottomRow(-1);
        this.reportData.setScrollTopRow(-1);
        this.reportData.setRowCountPerPage(MAX_ROW);
        final int rowPageCount = this.reportData.getRowPageCount();
        GridIterator gridIterator = new GridIterator() { // from class: com.jiuqi.office.excel.SimpleExportor.1
            int sheetIndex = 0;

            @Override // com.jiuqi.office.excel.GridIterator
            public boolean next() throws ExcelException {
                return this.sheetIndex < rowPageCount;
            }

            @Override // com.jiuqi.office.excel.GridIterator
            public String getTitle() {
                return String.valueOf(SimpleExportor.this.preSheetName) + (this.sheetIndex - 1);
            }

            @Override // com.jiuqi.office.excel.GridIterator
            public GridData getGridData() {
                GridData gridData = SimpleExportor.this.reportData.getPagedGridData(this.sheetIndex);
                this.sheetIndex++;
                return gridData;
            }
        };
        BatchExportor batchExportor = new BatchExportor(gridIterator);
        batchExportor.setToSingleFile(true);
        try {
            try {
                try {
                    batchExportor.Export(outStream);
                    this.reportData.setRowCountPerPage(oldRowCountPerPage);
                    this.reportData.setScrollBottomRow(localBottomRow);
                    this.reportData.setScrollTopRow(localTopRow);
                } catch (ExcelException e) {
                    throw e;
                }
            } catch (Exception e2) {
                e2.printStackTrace();
                this.reportData.setRowCountPerPage(oldRowCountPerPage);
                this.reportData.setScrollBottomRow(localBottomRow);
                this.reportData.setScrollTopRow(localTopRow);
            }
        } catch (Throwable th) {
            this.reportData.setRowCountPerPage(oldRowCountPerPage);
            this.reportData.setScrollBottomRow(localBottomRow);
            this.reportData.setScrollTopRow(localTopRow);
            throw th;
        }
    }

    public HashMap getHSSFFontMap() {
        return this.HSSFFontMap;
    }

    public void setHSSFFontMap(HashMap hSSFFontMap) {
        this.HSSFFontMap = hSSFFontMap;
    }

    private Workbook createWorkbook(int mode) {
        HSSFWorkbook sXSSFWorkbook;
        if (mode == 0) {
            sXSSFWorkbook = new HSSFWorkbook();
        } else if (1 == mode) {
            sXSSFWorkbook = new XSSFWorkbook();
        } else if (2 == mode) {
            sXSSFWorkbook = new SXSSFWorkbook();
        } else {
            throw new IllegalStateException("不支持导出excel模式");
        }
        return sXSSFWorkbook;
    }
}
